@@ -21,11 +21,11 @@ Registered trademarks are property of their respective owners.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -75,7 +75,7 @@ called post-construction as object set/get methods.
 
 =over 4
 
-=item app_id
+=item B<app_id>
 
 B<Required.>  An application ID generated for your login at
 L<http://cloud.scorm.com/>.
@@ -88,7 +88,7 @@ has 'app_id' => (
                  isa      => 'Str',
                 );
 
-=item secret_key
+=item B<secret_key>
 
 B<Required.>  A secret key that corresponds to the application ID,
 used for hashing parameters in the API request URLs.  Generated at
@@ -102,7 +102,7 @@ has 'secret_key' => (
                      isa      => 'Str',
                     );
 
-=item service_url
+=item B<service_url>
 
 The API service URL.  Defaults to "http://cloud.scorm.com/api".
 
@@ -116,7 +116,7 @@ has 'service_url' => (
                       default  => 'http://cloud.scorm.com/api',
                      );
 
-=item last_error_data
+=item B<last_error_data>
 
 Returns a listref representing the raw response data for the
 error(s) returned by the most recent ScormCloud service API call.
@@ -137,12 +137,12 @@ API call returns undef instead of the expected object.
 =cut
 
 has 'last_error_data' => (
-                         is       => 'rw',
-                         isa => 'ArrayRef',
-                         default => sub { return [] },
-                        );
+                          is      => 'rw',
+                          isa     => 'ArrayRef',
+                          default => sub { return [] },
+                         );
 
-=item last_error_msg
+=item B<last_error_msg>
 
 Return a error message representing the error(s) returned by the
 most recent ScormCloud service API call.
@@ -152,22 +152,21 @@ API call returns undef instead of the expected object.
 
 =cut
 
-my %error_codes = (
-);
+my %error_codes = ();
 
 sub last_error_msg
 {
     my ($self) = @_;
 
     my @msg = ();
-   
+
     foreach my $error (@{$self->last_error_data})
     {
         my $msg = $error->{msg};
-        $msg =~ s/^\s+//;
-        $msg =~ s/\s+$//;
-        $msg =~ s/\s+/ /;
-        $msg =~ s/ associated with appid \[.*?\]//g;
+        $msg =~ s/^\s+//msx;
+        $msg =~ s/\s+$//msx;
+        $msg =~ s/\s+/ /msx;
+        $msg =~ s/ associated with appid \[.*?\]//gmsx;
 
         push @msg, $msg;
     }
@@ -175,7 +174,7 @@ sub last_error_msg
     return join("\n", @msg);
 }
 
-=item lwp_user_agent
+=item B<lwp_user_agent>
 
 Set the user agent string used in API requests.  Defaults to "MyApp/1.0".
 
@@ -189,7 +188,7 @@ has 'lwp_user_agent' => (
                          default => 'MyApp/1.0',
                         );
 
-=item top_level_namespace
+=item B<top_level_namespace>
 
 Top-level namespace for API methods.  Defaults to "rustici".
 
@@ -202,7 +201,7 @@ has 'top_level_namespace' => (
                               default  => 'rustici',
                              );
 
-=item dump_request_url
+=item B<dump_request_url>
 
 Set to true to dump request URLs to STDOUT.  Default is false.
 
@@ -214,7 +213,7 @@ has 'dump_request_url' => (
                            default => 0,
                           );
 
-=item dump_response_xml
+=item B<dump_response_xml>
 
 Set to true to dump raw response XML to STDOUT.  Default is false.
 
@@ -226,7 +225,7 @@ has 'dump_response_xml' => (
                             default => 0,
                            );
 
-=item dump_response_data
+=item B<dump_response_data>
 
 Set to true to dump data from parsed response XML to STDOUT.
 Default is false.
@@ -241,7 +240,7 @@ has 'dump_response_data' => (
                              default => 0,
                             );
 
-=item dump_api_results
+=item B<dump_api_results>
 
 Set to true to dump results grabbed from response data by each API
 call.  Default is false.
@@ -256,7 +255,7 @@ has 'dump_api_results' => (
                            default => 0,
                           );
 
-=item die_on_bad_response
+=item B<die_on_bad_response>
 
 Set to true to die if the API response data is malformed or invalid
 for the given API method being called (mainly useful for testing).
@@ -308,6 +307,9 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-ScormCloud>.
 I will be notified, and then you'll automatically be notified of
 progress on your bug as I make changes.
 
+Patches more than welcome, especially via GitHub:
+L<https://github.com/larryl/ScormCloud>
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -318,6 +320,10 @@ You can also look for information at:
 
 =over 4
 
+=item * GitHub
+
+L<https://github.com/larryl/ScormCloud>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WebService-ScormCloud>
