@@ -8,11 +8,11 @@ WebService::ScormCloud::Types - type definitions for L<WebService::ScormCloud>
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -77,6 +77,9 @@ Please report any bugs or feature requests to C<bug-scormcloud at rt.cpan.org>,
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-ScormCloud>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+Patches more than welcome, especially via GitHub:
+L<https://github.com/larryl/ScormCloud>
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -87,6 +90,10 @@ You can also look for information at:
 
 =over 4
 
+=item * GitHub
+
+L<https://github.com/larryl/ScormCloud>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WebService-ScormCloud>
